EXPORTS
	?DeleteAssistanceData@CNpeApi@@QAEXK@Z @ 1 NONAME ; void CNpeApi::DeleteAssistanceData(unsigned long)
	?AdvisePowerMode@CNpeApi@@QAEXW4TNpePowerMode@@@Z @ 2 NONAME ; void CNpeApi::AdvisePowerMode(enum TNpePowerMode)
	??1CNpeApi@@UAE@XZ @ 3 NONAME ; CNpeApi::~CNpeApi(void)
	?NewL@CNpeApi@@SAPAV1@PAVMNpeObserver@@@Z @ 4 NONAME ; class CNpeApi * CNpeApi::NewL(class MNpeObserver *)
	?Version@CNpeApi@@QAEXAAVTVersion@@@Z @ 5 NONAME ; void CNpeApi::Version(class TVersion &)
	?ExtendedInterface@CNpeApi@@UAEPAXHPAX0@Z @ 6 NONAME ; void * CNpeApi::ExtendedInterface(int, void *, void *)
	?CancelPositionRequest@CNpeApi@@QAEXXZ @ 7 NONAME ; void CNpeApi::CancelPositionRequest(void)
	?SetGpsOptions@CNpeApi@@QAEXW4TNpeGpsMode@@H@Z @ 8 NONAME ; void CNpeApi::SetGpsOptions(enum TNpeGpsMode, int)
	?SetClientUsage@CNpeApi@@QAEXW4TNpeClientInfo@@@Z @ 9 NONAME ; void CNpeApi::SetClientUsage(enum TNpeClientInfo)
	?PositionRequest@CNpeApi@@QAEXABVTTime@@HHH@Z @ 10 NONAME ; void CNpeApi::PositionRequest(class TTime const &, int, int, int)
	?NewLC@CNpeApi@@SAPAV1@PAVMNpeObserver@@@Z @ 11 NONAME ; class CNpeApi * CNpeApi::NewLC(class MNpeObserver *)
	?DeliverAssistanceData@CNpeApi@@QAEXKAAVRLbsAssistanceDataReaderSet@@@Z @ 12 NONAME ; void CNpeApi::DeliverAssistanceData(unsigned long, class RLbsAssistanceDataReaderSet &)

